@@ -10,6 +10,9 @@
 #' 
 #' @param margin \link[base]{integer} scalar or \link[base]{vector}, see \link[stats]{addmargins}
 #' 
+#' @param fmt \link[base]{character} scalar, 
+#' C-style string format with a `%d` and an `%f%%` for the counts and proportions (order enforced).
+#' 
 #' @details 
 #' 
 #' Function [addProbs] provides the joint, marginal (using `margin = 1:2`) 
@@ -17,9 +20,14 @@
 #' probabilities of a two-dimensional contingency table.
 #' 
 #' @note 
-#' \link[base]{margin.table} (which is to be renamed as \link[base]{marginSums}) 
+#' \link[base]{margin.table} 
+#' (which is to be renamed as \link[base]{marginSums}) 
 #' is much slower than \link[base]{colSums}.
 #' 
+#' The use of argument `margin` is 
+#' the same as \link[stats]{addmargins},
+#' and different from \link[base]{proportions}!
+#' 
 #' @returns 
 #' Function [addProbs] returns an `'addProbs'` object, which inherits from \link[base]{table} and \link[base]{noquote}.
 #' 
@@ -27,15 +35,17 @@
 #' \link[base]{rowSums} \link[base]{colSums} \link[base]{proportions} 
 #' 
 #' @examples 
-#' (y1 = addProbs(table(warpbreaks$tension)))
+#' addProbs(table(warpbreaks$tension))
 #' 
-#' storage.mode(WorldPhones) = 'integer'
-#' (y2 = addProbs(WorldPhones))
+#' storage.mode(VADeaths) = 'integer'
+#' addProbs(VADeaths)
+#' addProbs(VADeaths, margin = 1L)
+#' rowSums(proportions(VADeaths, margin = 1L))
+#' addmargins(VADeaths, margin = 1L)
 #' 
-#' @keywords internal
 #' @importFrom stats addmargins
 #' @export
-addProbs <- function(A, margin = seq_len(nd)) {
+addProbs <- function(A, margin = seq_len(nd), fmt = '%d (%.1f%%)') {
   if (!length(A)) return(invisible())
   if (inherits(A, what = 'formula')) .Defunct('addProbs(xtabs(A, data = data, addNA = TRUE))')
   if (!is.array(A) || typeof(A) != 'integer') stop('input must be integer array')
@@ -58,7 +68,7 @@ addProbs <- function(A, margin = seq_len(nd)) {
   
   if (identical(margin, seq_len(nd))) {
     # joint probabilities
-    ret[] <- sprintf(fmt = '%d (%.1f%%)', ret, 1e2 * ret / sum(A))
+    ret[] <- sprintf(fmt = fmt, ret, 1e2 * ret / sum(A))
     #if (nd == 1L) {
     #  ret <- array(ret, dim = c(1L, dm + 1L), dimnames = list(NULL, names(ret)))
     #} # else do nothing
@@ -66,9 +76,9 @@ addProbs <- function(A, margin = seq_len(nd)) {
     if (length(margin) != 1L) stop('length of `margin` must be 1')
     if (margin == 1L) { # colSums
       if (nd == 1L) stop('already dealt with in the first `if`')
-      ret[] <- sprintf(fmt = '%d (%.1f%%)', ret, 1e2 * t.default(t.default(ret) / .colSums(A, m = dm[1L], n = dm[2L], na.rm = FALSE)))
+      ret[] <- sprintf(fmt = fmt, ret, 1e2 * t.default(t.default(ret) / .colSums(A, m = dm[1L], n = dm[2L], na.rm = FALSE)))
     } else if (margin == 2L) { # rowSums
-      ret[] <- sprintf(fmt = '%d (%.1f%%)', ret, 1e2 * ret / .rowSums(A, m = dm[1L], n = dm[2L], na.rm = FALSE))
+      ret[] <- sprintf(fmt = fmt, ret, 1e2 * ret / .rowSums(A, m = dm[1L], n = dm[2L], na.rm = FALSE))
     } else stop('wont come here')
   }
   ret[x == 0L] <- '.' # otherwise too crowded
