@@ -1,19 +1,19 @@
 
 
-#' @title Chapter 3
+#' @title Chapter 3: Some Basic Probability Concepts
 #' 
 #' @description 
 #' 
 #' Examples in Chapter 3, \emph{Some Basic Probability Concepts}.
 #' 
 #' @return 
-#' This is an example-only documentation.
+#' No function defined for Chapter 3.
 #' 
 # @seealso \link[stats]{addmargins} \link[base]{rowSums} \link[base]{colSums} \link[base]{proportions} 
 #' 
 #' @example inst/extexample/Chapter3.R 
 #' 
 #' @name Chapter03
-# @export
+NULL
 
 
